@@ -1,5 +1,5 @@
 from mydots import cli
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli.main()
